@@ -44,7 +44,7 @@ zenity_calendar (ZenityData *data, ZenityCalendarData *cal_data)
   glade_dialog = zenity_util_load_glade_file ("zenity_calendar_dialog");
 
   if (glade_dialog == NULL) {
-    data->exit_code = -1;
+    data->exit_code = zenity_util_return_exit_code (ZENITY_ERROR);
     return;
   }
 	
@@ -100,23 +100,23 @@ zenity_calendar_dialog_response (GtkWidget *widget, int response, gpointer data)
       gtk_calendar_get_date (GTK_CALENDAR (calendar), &day, &month, &year);
       date = g_date_new_dmy (year, month + 1, day);
       g_date_strftime (time_string, 127, zen_cal_data->date_format, date);
-      g_printerr ("%s\n", time_string);
+      g_print ("%s\n", time_string);
     
       if (date != NULL)
         g_date_free (date);
     
-      zen_data->exit_code = 0;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
       gtk_main_quit ();
       break;
 
     case GTK_RESPONSE_CANCEL:
-      zen_data->exit_code = 1;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_CANCEL);
       gtk_main_quit ();
       break;
 
     default:
       /* Esc dialog */
-      zen_data->exit_code = 1;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
     }
 }
